{% load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
	<meta http-equiv="Content-type" content="text/html; charset=utf-8"/>
	<meta http-equiv="Content-Language" content="en-us"/>
	<meta name="robots" content="NONE,NOARCHIVE"/>
	<title>{% blocktrans %}Index of {{ directory }}{% endblocktrans %}</title>
	<link rel="stylesheet" href="{{ STATIC_URL }}localdir/css/styles.css">
	<script type="text/javascript" src="{{ STATIC_URL }}admin/js/jquery.min.js"></script>
	<script type="text/javascript" src="{{ STATIC_URL }}localdir/js/script.js"></script>
</head>
<body class="localdir" data-fullpath="{{ fullpath }}">
<h1>{% blocktrans %}Index of {{ directory }}{% endblocktrans %}</h1>
<button id="select" type="button" class="select-button" data-select-text="{% trans "Select" %}">{% trans "Select current" %}</button>
<button onclick="window.close()" type="button" class="select-button">{% trans "Close" %}</button>
<div class="wrap">
	<div class="list">
		<ul>
			{% ifnotequal directory "/" %}
				<li><a id="up" href="../">../</a></li>
			{% endifnotequal %}
			{% for d in dirs %}
				<li class="dir"><a href="{{ d|urlencode }}">{{ d }}</a></li>
			{% endfor %}
			{% for f in files %}
				<li class="file">{{ f }}</li>
			{% endfor %}
		</ul>
	</div>
</div>
<span class="footer">
	{% blocktrans %}
		Double click at the directory name for to open it, or single click for to mark it for
select. When you selected directory click to the 'Select' button.
	{% endblocktrans %}
</span>
</body>
</html>