.localdir {
    font-family: "Lucida Grande", Verdana, Arial, sans-serif;
    margin: 0;
    padding: 0;
}

.localdir a:link, a:visited {
    color: #5b80b2;
    text-decoration: none;
}

.localdir a:hover {
    color: #036;
}

.localdir h1 {
    background-color: #417690;
    display: block;
    padding: 10px 10px;
    margin-top: 0;
    margin-bottom: 5px;
    color: #f4f379;
}

.localdir ul {
    margin: 0;
    padding: 0;
}

.localdir ul li {
    list-style-type: none;
    vertical-align: middle;
    padding-left: 30px;
    margin-bottom: 5px;
}

.localdir ul li a {
    padding-left: 5px;
}

.localdir ul li.dir {
    background: url(../img/folder.png) left center no-repeat;
    font-weight: bold;
}

.localdir ul li.dir.denyed {
    background: url(../img/folder-red.png) left center no-repeat;
}

.localdir ul li.file {
    color: lightgray;
    background: url(../img/unknown_file.png) left center no-repeat;
}

.localdir .wrap {
    margin: 5px;
    padding-top: 5px;
    border-top: 1px solid darkgray;

}

.localdir .list {
    overflow-y: auto;
    max-height: 550px;
}

.localdir .footer {
    display: block;
    margin: 5px;
    padding-top: 5px;
    border-top: 1px solid darkgray;
    max-height: 50px;
    color: darkgray;
    font-size: small;
}

.localdir .select-button {
    font-weight: bold;
    font-size: medium;
    margin-left: 10px;
}

.localdir .selected {
    padding-right: 5px;
    height: 30px;
    border: 1px solid #175280;
    color: #fff !important;
    -webkit-border-radius: 5px;
    border-radius: 5px;
    -webkit-box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.8);
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.8);
    cursor: pointer;
    background: #286da1;
    background: -moz-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #357db4), color-stop(100%, #1d5e91));
    background: -webkit-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: -o-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: -ms-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: linear-gradient(to bottom, #357db4 0%, #1d5e91 100%);
}

button {
    padding: 0 10px;
    height: 29px;
    border: 1px solid #175280;
    color: #fff;
    -webkit-border-radius: 5px;
    border-radius: 5px;
    -webkit-box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.8);
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.8);
    cursor: pointer;
    background: #286da1;
    background: -moz-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #357db4), color-stop(100%, #1d5e91));
    background: -webkit-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: -o-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: -ms-linear-gradient(top, #357db4 0%, #1d5e91 100%);
    background: linear-gradient(to bottom, #357db4 0%, #1d5e91 100%);
}